@@ -43,20 +43,20 @@ import bisect
 import sys
 
 
+from ligo.lw import lsctables
+from ligo.lw.utils import coincs as ligolw_coincs
+from ligo.lw.utils import process as ligolw_process
+from ligo.lw.utils import search_summary as ligolw_search_summary
+from ligo.lw.utils import time_slide as ligolw_time_slide
 import lal
-from glue import segments
-from glue.ligolw import lsctables
-from glue.ligolw.utils import coincs as ligolw_coincs
-from glue.ligolw.utils import process as ligolw_process
-from glue.ligolw.utils import search_summary as ligolw_search_summary
-from glue.ligolw.utils import time_slide as ligolw_time_slide
+from ligo import segments
 from . import burca
 from . import SimBurstUtils
 
 
 __author__ = "Kipp Cannon <kipp.cannon@ligo.org>"
-from git_version import date as __date__
-from git_version import version as __version__
+from .git_version import date as __date__
+from .git_version import version as __version__
 
 
 #
@@ -69,16 +69,40 @@ from git_version import version as __version__
 
 
 #
-# allow burst event lists to be searched using the bisect module
+# Construct a subclass of the sngl_burst row class with the methods that
+# are needed
 #
 
 
-def sngl_burst___cmp__(self, other):
-	# compare self's peak time to the LIGOTimeGPS instance other
-	return cmp(self.peak, other)
+class SnglBurst(lsctables.SnglBurst):
+	__slots__ = ()
+
+	#
+	# compare self's end time to the LIGOTimeGPS instance other.
+	# allows bisection searches by GPS time to find ranges of triggers
+	# quickly
+	#
+
+	def __lt__(self, other):
+		return self.end < other
+
+	def __le__(self, other):
+		return self.end <= other
+
+	def __eq__(self, other):
+		return self.end == other
+
+	def __ne__(self, other):
+		return self.end != other
+
+	def __ge__(self, other):
+		return self.end >= other
+
+	def __gt__(self, other):
+		return self.end > other
 
 
-lsctables.SnglBurst.__cmp__ = sngl_burst___cmp__
+lsctables.SnglBurstTable.RowType = lsctables.SnglBurst = SnglBurst
 
 
 #
