@@ -7,9 +7,9 @@ crash_dumps_octave_core(0);
 ## check module load
 disp("checking module load ...");
 lalburst;
-assert(exist("lalburst", "var"));
+assert(exist("lalburst"));
 lal;
-assert(exist("lal", "var"));
+assert(exist("lal"));
 disp("PASSED module load");
 
 ## check object parent tracking
@@ -29,3 +29,6 @@ disp("PASSED object parent tracking");
 
 ## passed all tests!
 disp("PASSED all tests");
+if exist("swig_exit")
+   swig_exit;
+endif
